@@ -1,5 +1,5 @@
 from flask import Blueprint
-from . import Emailer
+from .emailer import Emailer
 
 bp = Blueprint('email', __name__, template_folder='templates')
 
